<?php

/**
 * @file
 */

/**
 * Menu callback; displays the ezshop module settings page.
 */
function ezshop_admin_settings(&$form_state) {
  $form['ezshop_content_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Product content types for webshopping'),
    '#options' => node_get_types('names'),
    '#default_value' => variable_get('ezshop_content_types', array()),
  );
  $form['ezshop_linkweight'] = array(
    '#type' => 'textfield',
    '#title' => t('Weight of the %add_to_cart link on product pages', array('%add_to_cart' => t('Add to cart'))),
    '#default_value' => variable_get('ezshop_linkweight', 99),
    '#maxlength' => 3,
    '#size' => 5,
  );
  $form['ezshop_ordermail'] = array(
    '#type' => 'textfield',
    '#title' => t('Email address'),
    '#description' => t('The orders will be sent to this address. Leave it empty for %site_mail.', array('%site_mail' => variable_get('site_mail', ini_get('sendmail_from')))),
    '#default_value' => variable_get('ezshop_ordermail', FALSE),
    '#size' => 30,
  );
  $form['ezshop_mailview'] = array(
    '#type' => 'textfield',
    '#title' => t('Email view'),
    '#description' => t('The view and display which will be used for email. You can freely customize how the orders are sent in the email by creating a custom view.'),
    '#default_value' => variable_get('ezshop_mailview', 'EZShop:block_1'),
  );

  return system_settings_form($form);
}

/**
 * Validate ezshop_admin_settings form submissions.
 */
function ezshop_admin_settings_validate($form, &$form_state) {
  if (empty($form_state['values']['ezshop_ordermail'])) {
    $form_state['values']['ezshop_ordermail'] = variable_get('site_mail', ini_get('sendmail_from'));
  }

  if (!valid_email_address($form_state['values']['ezshop_ordermail'])) {
    form_set_error('ezshop_ordermail', t('Invalid e-mail address.'));
  }

  $weight = $form_state['values']['ezshop_linkweight'];
  if (!is_numeric($weight) || $weight < -99 || $weight > 99) {
    form_set_error('ezshop_linkweight', t('Weight of the link must be an integer between -99 and 99.'));
  }
}
