<?php

/**
 * @file
 */

/**
 * Menu callback; adds the node to the cart.
 */
function ezshop_add_item($node) {
  global $user;

  if (!$user->uid) {
    return; // Not logged in.
  }

  if (!in_array($node->type, variable_get('ezshop_content_types', array()))) {
    return; // Not a product.
  }

  $cnt = db_result(db_query('SELECT cnt FROM {ezshop_items} WHERE uid = %d AND nid = %d', $user->uid, $node->nid));
  if (!$cnt) {
    // This user does not have this node yet.
    db_query('INSERT INTO {ezshop_items} (uid, nid, cnt) VALUES (%d, %d, 1)', $user->uid, $node->nid);
  }
  else {
    db_query('UPDATE {ezshop_items} SET cnt = cnt + 1 WHERE uid = %d AND nid = %d', $user->uid, $node->nid);
  }

  drupal_set_message(t('%title has been added to the cart.', array('%title' => $node->title)));
  drupal_goto('node/'. $node->nid);
}

/**
 * Menu callback; removes the node from the cart.
 */
function ezshop_delete_item($node) {
  global $user;

  if (!$user->uid) {
    return; // Not logged in.
  }

  if (!in_array($node->type, variable_get('ezshop_content_types', array()))) {
    return; // Not a product.
  }

  db_query('DELETE FROM {ezshop_items} WHERE uid = %d AND nid = %d', $user->uid, $node->nid);

  drupal_set_message(t('%title has been removed from the cart.', array('%title' => $node->title)));
  drupal_goto('node/'. $node->nid);
}

/**
 * Menu callback; order the selected products.
 */
function ezshop_order_form(&$form_state) {
  global $user;

  list($view_name, $display) = explode(':', variable_get('ezshop_mailview', 'EZShop:block_1'));

  $view = views_get_view($view_name);
  if (!isset($view)) {
    drupal_set_message(t('The view which is set as order email does not exists.'), 'error');
    return;
  }
  $message = $view->preview($display, array());

  $form['message'] = array(
    '#type' => 'markup',
    '#value' => $message,
  );

  $cnt = db_result(db_query('SELECT count(uid) FROM {ezshop_items} WHERE uid = %d', $user->uid));
  if ($cnt > 0) {
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Order'),
    );
  }

  return $form;
}

function ezshop_order_form_submit($form, &$form_state) {
  global $language, $user;

  $shop_email = variable_get('ezshop_ordermail', variable_get('site_mail', ini_get('sendmail_from')));
  $params['body'] = $form['message']['#value'];

  // The first mail should be sent to the shop owner (in default language).
  $message = drupal_mail('ezshop', 'order', $shop_email, language_default(), $params, $user->mail);
  if (!$message['result']) {
    return;
  }

  // A copy should be sent to the customer (in actual language).
  $message = drupal_mail('ezshop', 'order_copy', $user->mail, $language, $params, $shop_email);
  if (!$message['result']) {
    return;
  }

  flood_register_event('ezshop');
  watchdog('ezshop', '%name-from sent an ezshop order.', array('%name-from' => $user->name .' ['. $user->mail .']'));

  db_query('DELETE FROM {ezshop_items} WHERE uid = %d', $user->uid);
  drupal_set_message(t('Your order has been sent. Your cart is now empty.'));

  $form_state['redirect'] = '<front>';
}

/**
 * A custom theme function.
 *
 * @ingroup themeable
 */
function theme_ezshop_add_item_link($node) {
  $output = '<div class="ezshop-add">';
  $output .= l(t('Add to cart'), 'cart/add/'. $node->nid, array('query' => drupal_get_destination()));
  $output .= '</div>';

  return $output;
}
